==> tine20-allinone_2019.12.5.tar.bz2: Setup/js/Setup-lang-ro_RO-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Romanian (Romania) (http://www.transifex.com/tine20/tine20/language/ro_RO/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ro_RO\nPlural-Forms: nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Backend"
: ""

, "Standard IMAP"
: "Standard IMAP"

, "Standard SMTP"
: "Standard SMTP"

, "Imap"
: "Imap"

, "Hostname"
: ""

, "Username"
: "Nume utilizator"

, "Password"
: "Parola"

, "Port"
: "Port"

, "Secure Connection"
: ""

, "None"
: ""

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: ""

, "No"
: "Nu"

, "Yes"
: "Da"

, "Append domain to login name"
: ""

, "Use email address as login name"
: ""

, "Cyrus Admin"
: ""

, "Cyrus Admin Password"
: ""

, "Use proxy auth"
: ""

, "Smtp"
: "Smtp"

, "Authentication"
: ""

, "Login"
: ""

, "Plain"
: ""

, "Primary Domain"
: ""

, "Secondary Domains (comma separated)"
: ""

, "Notifications service address"
: ""

, "Notification Username"
: ""

, "Notification Password"
: ""

, "Notifications local client (hostname or IP address)"
: ""

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "MySql Hostname"

, "MySql Database"
: ""

, "MySql User"
: "MySql User"

, "MySql Password"
: ""

, "MySql Port"
: "MySql Port"

, "User or UID"
: ""

, "Group or GID"
: ""

, "Home Template"
: ""

, "Password Scheme"
: ""

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "I have read the license agreement and accept it"
: ""

, "License Agreement"
: ""

, "I have read the privacy agreement and accept it"
: ""

, "Privacy Agreement"
: ""

, "Accept Terms and Conditions"
: ""

, "Performing Environment Checks..."
: ""

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: ""

, "Result"
: "Resultat"

, "Error"
: "Eroare"

, "Run setup tests"
: ""

, "Ignore setup tests"
: ""

, "Install application"
: ""

, "File"
: "Fişier"

, "Setup Authentication"
: ""

, "Database"
: ""

, "User"
: "Utilizator"

, "Prefix"
: "Prefix"

, "Logging"
: ""

, "Filename"
: "NumeFişier"

, "Priority"
: "Prioritate"

, "Caching"
: ""

, "Lifetime (seconds)"
: ""

, "Path"
: ""

, "Queue"
: ""

, "Session"
: "Sesiune"

, "Temporary files"
: "Fişiere Temporare"

, "Temporary Files Path"
: ""

, "Filestore directory"
: ""

, "Filestore Path"
: ""

, "Addressbook Map panel"
: ""

, "Map panel"
: ""

, "disabled"
: ""

, "enabled"
: ""

, "Config file is not writable"
: ""

, "Save config"
: ""

, "Download config file"
: ""

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Terms and Conditions"
: ""

, "Setup Checks"
: ""

, "Config Manager"
: ""

, "Authentication/Accounts"
: ""

, "Email"
: "Email"

, "Application Manager"
: ""

, "Delete all existing users and groups"
: ""

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: ""

, "TLS client certificate"
: ""

, "Initial Admin User"
: ""

, "Initial admin login name"
: ""

, "Initial admin Password"
: ""

, "Password confirmation"
: ""

, "Authentication provider"
: ""

, "Try to split username"
: ""

, "Account canonical form"
: ""

, "Account domain name"
: ""

, "Account domain short name"
: ""

, "Host"
: "Host"

, "Login name"
: ""

, "Bind requires DN"
: ""

, "Start TLS"
: ""

, "Base DN"
: ""

, "Search filter"
: ""

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: ""

, "Default user group name"
: ""

, "Default admin group name"
: ""

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: ""

, "User can change password"
: ""

, "Enable password policy"
: ""

, "Only ASCII"
: "Numai ASCII"

, "Minimum length"
: ""

, "Minimum word chars"
: ""

, "Minimum uppercase chars"
: ""

, "Minimum special chars"
: ""

, "Minimum numbers"
: ""

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: ""

, "Redirect Url (redirect to login screen if empty)"
: ""

, "Redirect Always (if No, only redirect after logout)"
: ""

, "Redirect to referring site, if exists"
: ""

, "Password encoding"
: ""

, "des"
: ""

, "crypt"
: "crypt"

, "blowfish_crypt"
: "blowfish_crypt"

, "md5_crypt"
: "md5_crypt"

, "ext_crypt"
: "ext_crypt"

, "md5"
: "md5"

, "smd5"
: "smd5"

, "sha"
: "sha"

, "ssha"
: "ssha"

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: ""

, "User Filter"
: ""

, "User Search Scope"
: ""

, "Groups DN"
: ""

, "Group Filter"
: ""

, "Group Search Scope"
: ""

, "Use Rfc 2307 bis"
: ""

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: ""

, "Max User Id"
: ""

, "Min Group Id"
: ""

, "Max Group Id"
: ""

, "Group UUID Attribute name"
: ""

, "User UUID Attribute name"
: ""

, "Readonly access"
: ""

, "Save config and install"
: ""

, "Passwords don't match"
: ""

, "Should not be empty"
: ""

, "Setup"
: ""

, "Application, Applications"
: [
  "Aplicaţie"
 ,"Aplicaţii"
 ,"Aplicaţii"

]
, "Name"
: "Nume"

, "Enabled"
: ""

, "Order"
: ""

, "Installed Version"
: ""

, "Available Version"
: ""

, "Status"
: "Status"

, "Depends on"
: ""

, "Uninstall application"
: ""

, "Update application"
: ""

, "Go to {0} login"
: ""

, "uninstall"
: ""

, "Do you really want to uninstall the application(s)?"
: ""

, "This may take a while"
: ""

, "Dependency Violation"
: ""

, "CLI Required"
: ""

, "Application"
: "Aplicaţie"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Setup/js/Setup-lang-ro_RO-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Romanian (Romania) (http://www.transifex.com/tine20/tine20/language/ro_RO/)\nLanguage: ro_RO\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: ""

, "License Agreement"
: ""

, "I have read the privacy agreement and accept it"
: ""

, "Privacy Agreement"
: ""

, "Accept Terms and Conditions"
: ""

, "Backend"
: ""

, "Standard IMAP"
: "Standard IMAP"

, "Standard SMTP"
: "Standard SMTP"

, "Imap"
: "Imap"

, "Hostname"
: ""

, "Username"
: "Nume utilizator"

, "Password"
: "Parola"

, "Port"
: "Port"

, "Secure Connection"
: ""

, "None"
: ""

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: ""

, "No"
: "Nu"

, "Yes"
: "Da"

, "Append domain to login name"
: ""

, "Use email address as login name"
: ""

, "Cyrus Admin"
: ""

, "Cyrus Admin Password"
: ""

, "Use proxy auth"
: ""

, "Smtp"
: "Smtp"

, "Authentication"
: ""

, "Login"
: ""

, "Plain"
: ""

, "Primary Domain"
: ""

, "Secondary Domains (comma separated)"
: ""

, "Notifications service address"
: ""

, "Notification Username"
: ""

, "Notification Password"
: ""

, "Notifications local client (hostname or IP address)"
: ""

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "MySql Hostname"

, "MySql Database"
: ""

, "MySql User"
: "MySql User"

, "MySql Password"
: ""

, "MySql Port"
: "MySql Port"

, "User or UID"
: ""

, "Group or GID"
: ""

, "Home Template"
: ""

, "Password Scheme"
: ""

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "Terms and Conditions"
: ""

, "Setup Checks"
: ""

, "Config Manager"
: ""

, "Authentication/Accounts"
: ""

, "Email"
: "Email"

, "Application Manager"
: ""

, "Setup"
: ""

, "Name"
: "Nume"

, "Enabled"
: ""

, "Order"
: ""

, "Installed Version"
: ""

, "Available Version"
: ""

, "Status"
: "Status"

, "Depends on"
: ""

, "Install application"
: ""

, "Uninstall application"
: ""

, "Update application"
: ""

, "Go to {0} login"
: ""

, "uninstall"
: ""

, "Do you really want to uninstall the application(s)?"
: ""

, "This may take a while"
: ""

, "Dependency Violation"
: ""

, "CLI Required"
: ""

, "Delete all existing users and groups"
: ""

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: ""

, "TLS client certificate"
: ""

, "Initial Admin User"
: ""

, "Initial admin login name"
: ""

, "Initial admin Password"
: ""

, "Password confirmation"
: ""

, "Authentication provider"
: ""

, "Try to split username"
: ""

, "Account canonical form"
: ""

, "Account domain name"
: ""

, "Account domain short name"
: ""

, "Host"
: "Host"

, "Login name"
: ""

, "Bind requires DN"
: ""

, "Start TLS"
: ""

, "Base DN"
: ""

, "Search filter"
: ""

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: ""

, "Default user group name"
: ""

, "Default admin group name"
: ""

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: ""

, "User can change password"
: ""

, "Enable password policy"
: ""

, "Only ASCII"
: "Numai ASCII"

, "Minimum length"
: ""

, "Minimum word chars"
: ""

, "Minimum uppercase chars"
: ""

, "Minimum special chars"
: ""

, "Minimum numbers"
: ""

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: ""

, "Redirect Url (redirect to login screen if empty)"
: ""

, "Redirect Always (if No, only redirect after logout)"
: ""

, "Redirect to referring site, if exists"
: ""

, "Password encoding"
: ""

, "des"
: ""

, "crypt"
: "crypt"

, "blowfish_crypt"
: "blowfish_crypt"

, "md5_crypt"
: "md5_crypt"

, "ext_crypt"
: "ext_crypt"

, "md5"
: "md5"

, "smd5"
: "smd5"

, "sha"
: "sha"

, "ssha"
: "ssha"

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: ""

, "User Filter"
: ""

, "User Search Scope"
: ""

, "Groups DN"
: ""

, "Group Filter"
: ""

, "Group Search Scope"
: ""

, "Use Rfc 2307 bis"
: ""

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: ""

, "Max User Id"
: ""

, "Min Group Id"
: ""

, "Max Group Id"
: ""

, "Group UUID Attribute name"
: ""

, "User UUID Attribute name"
: ""

, "Readonly access"
: ""

, "Save config and install"
: ""

, "Save config"
: ""

, "Passwords don't match"
: ""

, "Should not be empty"
: ""

, "Performing Environment Checks..."
: ""

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: ""

, "Result"
: "Resultat"

, "Error"
: "Eroare"

, "Run setup tests"
: ""

, "Ignore setup tests"
: ""

, "Application, Applications"
: [
  "Aplicaţie"
 ,"Aplicaţii"
 ,"Aplicaţii"

]
, "File"
: "Fişier"

, "Setup Authentication"
: ""

, "Database"
: ""

, "User"
: "Utilizator"

, "Prefix"
: "Prefix"

, "Logging"
: ""

, "Filename"
: "NumeFişier"

, "Priority"
: "Prioritate"

, "Caching"
: ""

, "Lifetime (seconds)"
: ""

, "Path"
: ""

, "Queue"
: ""

, "Session"
: "Sesiune"

, "Temporary files"
: "Fişiere Temporare"

, "Temporary Files Path"
: ""

, "Filestore directory"
: ""

, "Filestore Path"
: ""

, "Addressbook Map panel"
: ""

, "Map panel"
: ""

, "disabled"
: ""

, "enabled"
: ""

, "Config file is not writable"
: ""

, "Download config file"
: ""

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: "Aplicaţie"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
